#coding:utf-8
import os
import smbus
import Adafruit_BMP.BMP085 as bmp
#-------------------------------------------------------------------------------
# Классы-обертки для датчиков.
# Пока не реализована обработка ошибок ввода/вывода
# OldBean 17.01.18
#-------------------------------------------------------------------------------
class DS18B20(object): # Класс датчика температуры DS18B20
  path = "/sys/bus/w1/devices"
  def __init__(self, id):
    self._id = id
    self._fn = DS18B20.path + ("/28-%012x/w1_slave" % (id))

  def ReadRaw(self): # Чтение "сырых" данных датчика температуры (из файла fn)
    f = open(self._fn, 'r')
    lines = f.readlines()
    f.close()
    return lines

  @property
  def T(self): # Получение значения температуры 
    lines = self.ReadRaw()
    while lines[0].strip()[-3:] != 'YES': # Пока преобразование не закончено
      lines = self.ReadRaw()
    pos = lines[1].find('t=') # Значение температуры после 't='
    if pos != -1:
      return float(lines[1][pos + 2:])/1000
    return -1

  @staticmethod
  def IDs(): # Возвращает список ID всех подключенных датчиков DS18B20
    fnl = os.listdir(DS18B20.path)
    idl = []
    for fn in fnl:
      if fn[:3] == "28-":
        idl.append(int(fn[-12:], 16))
    return idl
#-------------------------------------------------------------------------------
class BMP180(object): # Класс датчика атмосферного давления BMP180
  def __init__(self):
    self._sensor = bmp.BMP085()
  
  @property
  def P(self):
    return self._sensor.read_pressure()/133.322 # Паскали -> в мм.рт.ст.

  @property
  def T(self):
    return self._sensor.read_temperature()
#-------------------------------------------------------------------------------
class RMS(object): # Класс датчика среднеквадратичного напряжения сети
  def __init__(self, addr = 0x05, bus = smbus.SMBus(1)):
    self._addr = addr
    self._bus = bus

  @property
  def V(self):
    return self._bus.read_byte(self._addr) + 100
#-------------------------------------------------------------------------------
if __name__ == "__main__": # Тестирование классов модуля sens
  print "\nДатчики DS18B20"
  tsIDs = DS18B20.IDs() # Список ID всех датчиков DS18B20 на шине 1-wire
  if len(tsIDs) == 0:
    print "Датчики отсутствуют"
  else:
    for id in tsIDs:
      ts = DS18B20(id) # Создаем объект (датчик DS18B20)
      temperature = ts.T # Измеряем температуру этим датчиком
      print "0x%012x :% 7.3f°C" % (id, temperature)

  print "\nДатчик BMP180"
  try:
    bmp = BMP180()
    print "Давление: \t%5.1f мм.рт.ст." % (bmp.P)
    print "Температура:\t%5.2f°C" % (bmp.T)
  except:
    print "Датчик отсутстует или неисправен"

  print "\nДатчик RMS"
  try:
    vs = RMS(0x05) # Создаем объект - датчик RMS
    print "Среднеквадратичное напряжение: %d V" % (vs.V) # Измеряем и выводим напругу
  except:
    print "Датчик отсутстует или неисправен"
